@@ -591,6 +591,8 @@ pragha_lastfm_tags_corrected_dialog (GtkButton *button, PraghaLastfmPlugin *plug
 	}
 
 	dialog = pragha_tags_dialog_new();
+	gtk_window_set_transient_for (GTK_WINDOW(dialog),
+		GTK_WINDOW(pragha_application_get_window (priv->pragha)));
 
 	g_signal_connect (G_OBJECT (dialog), "response",
 	                  G_CALLBACK (pragha_corrected_by_lastfm_dialog_response), plugin);
@@ -601,27 +603,6 @@ pragha_lastfm_tags_corrected_dialog (GtkButton *button, PraghaLastfmPlugin *plug
 	gtk_widget_show (dialog);
 }
 
-void
-pragha_lastfm_set_tiny_button (GtkWidget *button)
-{
-	GtkCssProvider *provider;
-	provider = gtk_css_provider_new ();
-	gtk_css_provider_load_from_data (provider,
-	                                 "#tiny-button {\n"
-	                                 " -GtkButton-default-border : 0px;\n"
-	                                 " -GtkButton-default-outside-border : 0px;\n"
-	                                 " -GtkButton-inner-border: 0px;\n"
-	                                 " -GtkWidget-focus-line-width: 0px;\n"
-	                                 " -GtkWidget-focus-padding: 0px;\n"
-	                                 " padding: 1px;}",
-	                                 -1, NULL);
-	gtk_style_context_add_provider (gtk_widget_get_style_context (button),
-	                                GTK_STYLE_PROVIDER (provider),
-	                                GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-	gtk_widget_set_name (button, "tiny-button");
-	g_object_unref (provider);
-}
-
 static GtkWidget*
 pragha_lastfm_tag_suggestion_button_new (PraghaLastfmPlugin *plugin)
 {
@@ -638,7 +619,7 @@ pragha_lastfm_tag_suggestion_button_new (PraghaLastfmPlugin *plugin)
 	g_signal_connect(G_OBJECT(ntag_lastfm_button), "clicked",
 	                 G_CALLBACK(pragha_lastfm_tags_corrected_dialog), plugin);
 
-	pragha_lastfm_set_tiny_button (ntag_lastfm_button);
+	pragha_hig_set_tiny_button (ntag_lastfm_button);
 	gtk_image_set_pixel_size (GTK_IMAGE(image), 12);
 
 	return ntag_lastfm_button;
@@ -1817,7 +1798,6 @@ pragha_lastfm_plugin_append_setting (PraghaLastfmPlugin *plugin)
 	lastfm_pass = gtk_entry_new ();
 	gtk_entry_set_max_length (GTK_ENTRY(lastfm_pass), LASTFM_PASS_LEN);
 	gtk_entry_set_visibility (GTK_ENTRY(lastfm_pass), FALSE);
-	gtk_entry_set_invisible_char (GTK_ENTRY(lastfm_pass), '*');
 	gtk_entry_set_activates_default (GTK_ENTRY(lastfm_pass), TRUE);
 
 	pragha_hig_workarea_table_add_row (table, &row, lastfm_plabel, lastfm_pass);
