@@ -2386,6 +2386,8 @@ pragha_library_pane_edit_tags_action (GtkAction *action, PraghaLibraryPane *libr
 	PraghaMusicobject *omobj = NULL;
 
 	dialog = pragha_tags_dialog_new();
+	gtk_window_set_transient_for (GTK_WINDOW(dialog),
+		GTK_WINDOW(gtk_widget_get_toplevel(GTK_WIDGET(library))));
 
 	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(library->library_tree));
 	sel = gtk_tree_selection_count_selected_rows(selection);
@@ -2664,6 +2666,11 @@ pragha_library_pane_tree_new(PraghaLibraryPane *clibrary)
 	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(library_tree), FALSE);
 	gtk_tree_view_set_show_expanders(GTK_TREE_VIEW(library_tree), TRUE);
 
+	/* Set sidebar style */
+
+	gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET(library_tree)),
+	                             GTK_STYLE_CLASS_SIDEBAR);
+
 	/* Selection mode is multiple */
 
 	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(library_tree));
@@ -2723,7 +2730,6 @@ pragha_library_pane_create_widget (PraghaLibraryPane *library)
 	                                GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW(library_tree_scroll),
 	                                     GTK_SHADOW_IN);
-	gtk_container_set_border_width (GTK_CONTAINER(library_tree_scroll), 2);
 
 	/* Package all */
 
@@ -2857,6 +2863,7 @@ static void
 pragha_library_pane_init (PraghaLibraryPane *library)
 {
 	gtk_orientable_set_orientation (GTK_ORIENTABLE (library), GTK_ORIENTATION_VERTICAL);
+	g_object_set (G_OBJECT(library), "spacing", 2, NULL);
 
 	/* Get usefuls instances */
 
@@ -2878,9 +2885,6 @@ pragha_library_pane_init (PraghaLibraryPane *library)
 
 	pragha_library_pane_create_widget (library);
 
-	gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET(library)),
-	                             GTK_STYLE_CLASS_SIDEBAR);
-
 	/* Create context menus */
 
 	library->library_pane_context_menu = pragha_library_pane_header_context_menu_new (library);
