@@ -266,7 +266,7 @@ static GtkToggleActionEntry toggles_entries[] = {
 	 "F9", "Lateral panel", NULL,
 	TRUE},
 	{"Lateral panel2", NULL, N_("Secondary lateral panel"),
-	 "<Control>F9", "Secondary lateral panel", NULL,
+	 "<Shift>F9", "Secondary lateral panel", NULL,
 	FALSE},
 	{"Playback controls below", NULL, N_("Playback controls below"),
 	 NULL, "Show playback controls below", G_CALLBACK(show_controls_below_action),
@@ -666,7 +666,7 @@ static void community_action(GtkAction *action, PraghaApplication *pragha)
 
 static void wiki_action(GtkAction *action, PraghaApplication *pragha)
 {
-	const gchar *uri = "http://pragha-music-player.github.io/wiki";
+	const gchar *uri = "https://github.com/pragha-music-player/pragha/wiki/Welcome-to-the-Pragha-Wiki";
 	open_url(uri, pragha_application_get_window(pragha));
 }
 
@@ -1473,7 +1473,7 @@ static const gchar *menu_ui = \
 		NEW_ACCEL_ITEM("Jump to playing song",                 "&lt;Control&gt;J",     "win", "jump-song") \
 		SEPARATOR \
 		NEW_ACCEL_ITEM     ("Show lateral _panel",             "F9",                   "win", "sidebar1") \
-		NEW_ACCEL_ITEM     ("Show secondary lateral panel",    "&lt;Control&gt;F9",    "win", "sidebar2") \
+		NEW_ACCEL_ITEM     ("Show secondary lateral panel",    "&lt;Shift&gt;F9",      "win", "sidebar2") \
 		NEW_ACCEL_ITEM     ("Show menubar",                    "&lt;Control&gt;M",     "win", "menubar") \
 		NEW_ITEM           ("Show status bar",                                         "win", "status-bar") \
 		SEPARATOR \
