@@ -66,7 +66,6 @@ struct _PreferencesDialog {
 	GtkWidget *system_titlebar_w;
 #endif
 	GtkWidget *small_toolbar_w;
-	GtkWidget *use_hint_w;
 	GtkWidget *album_art_w;
 	GtkWidget *album_art_size_w;
 	GtkWidget *album_art_pattern_w;
@@ -346,9 +345,6 @@ pragha_preferences_dialog_restore_changes (PreferencesDialog *dialog)
 	else
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dialog->small_toolbar_w), FALSE);
 
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dialog->use_hint_w),
-		pragha_preferences_get_use_hint(dialog->preferences));
-
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(dialog->album_art_w),
 		pragha_preferences_get_show_album_art(dialog->preferences));
 
@@ -407,7 +403,7 @@ pragha_preferences_dialog_accept_changes (PreferencesDialog *dialog)
 	GSList *list, *library_dir = NULL, *folder_scanned = NULL;
 	gchar *window_state_sink = NULL;
 	const gchar *album_art_pattern;
-	gboolean show_album_art, instant_search, approximate_search, restore_playlist, add_recursively, use_hint;
+	gboolean show_album_art, instant_search, approximate_search, restore_playlist, add_recursively;
 	gboolean test_change, pref_setted, pref_toggled, library_locked;
 #if GTK_CHECK_VERSION (3, 12, 0)
 	gboolean system_titlebar;
@@ -563,9 +559,6 @@ pragha_preferences_dialog_accept_changes (PreferencesDialog *dialog)
 		gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(dialog->add_recursively_w));
 	pragha_preferences_set_add_recursively(dialog->preferences, add_recursively);
 
-	use_hint = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(dialog->use_hint_w));
-	pragha_preferences_set_use_hint(dialog->preferences, use_hint);
-
 	show_album_art =
 		gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(dialog->album_art_w));
 	pragha_preferences_set_show_album_art(dialog->preferences, show_album_art);
@@ -829,8 +822,6 @@ pragha_preferences_dialog_init_settings(PreferencesDialog *dialog)
 				gtk_combo_box_set_active(GTK_COMBO_BOX(dialog->window_state_combo_w), 3);
 		}
 	}
-	if (pragha_preferences_get_use_hint(dialog->preferences))
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dialog->use_hint_w), TRUE);
 
 	if (pragha_preferences_get_instant_search(dialog->preferences))
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dialog->instant_filter_w), TRUE);
@@ -1054,7 +1045,7 @@ pref_create_appearance_page(PreferencesDialog *dialog)
 #if GTK_CHECK_VERSION (3, 12, 0)
 	GtkWidget *system_titlebar;
 #endif
-	GtkWidget *use_hint, *album_art, *small_toolbar;
+	GtkWidget *album_art, *small_toolbar;
 	GtkWidget *album_art_pattern_label, *album_art_size, *album_art_size_label, *album_art_pattern;
 	guint row = 0;
 
@@ -1073,11 +1064,6 @@ pref_create_appearance_page(PreferencesDialog *dialog)
 	small_toolbar = gtk_check_button_new_with_label(_("Use small icons on the toolbars"));
 	pragha_hig_workarea_table_add_wide_control(table, &row, small_toolbar);
 
-	pragha_hig_workarea_table_add_section_title(table, &row, _("Playlist"));
-
-	use_hint = gtk_check_button_new_with_label(_("Highlight rows on current playlist"));
-	pragha_hig_workarea_table_add_wide_control(table, &row, use_hint);
-
 	pragha_hig_workarea_table_add_section_title(table, &row, _("Controls"));
 
 	album_art = gtk_check_button_new_with_label(_("Show Album art in Panel"));
@@ -1103,7 +1089,6 @@ pref_create_appearance_page(PreferencesDialog *dialog)
 	dialog->system_titlebar_w = system_titlebar;
 #endif
 	dialog->small_toolbar_w = small_toolbar;
-	dialog->use_hint_w = use_hint;
 	dialog->album_art_w = album_art;
 	dialog->album_art_size_w = album_art_size;
 	dialog->album_art_pattern_w = album_art_pattern;
@@ -1270,8 +1255,8 @@ PreferencesDialog *
 pragha_preferences_dialog_new (GtkWidget *parent)
 {
 	PreferencesDialog *dialog;
-	GtkWidget *header, *pref_notebook;
-
+	PraghaHeader *header;
+	GtkWidget *pref_notebook;
 	GtkWidget *audio_vbox, *appearance_vbox, *library_vbox, *general_vbox, *desktop_vbox;
 	GtkWidget *label_appearance, *label_library, *label_general;
 	#ifdef HAVE_LIBPEAS
@@ -1346,11 +1331,13 @@ pragha_preferences_dialog_new (GtkWidget *parent)
 
 	/* Add to dialog */
 
-	header = sokoke_xfce_header_new (_("Preferences of Pragha"), "pragha");
+	header = pragha_header_new ();
+	pragha_header_set_title (header, _("Preferences of Pragha"));
+	pragha_header_set_icon_name (header, "pragha");
 
-	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog->widget))), header, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog->widget))), GTK_WIDGET(header), FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog->widget))), pref_notebook, TRUE, TRUE, 0);
-	gtk_widget_show_all (header);
+	gtk_widget_show_all (GTK_WIDGET(header));
 	gtk_widget_show (pref_notebook);
 
 	/* Setup signal handlers */
