@@ -415,11 +415,11 @@ prefrences_change_icon_size (PraghaPreferences *preferences,
 {
 	GIcon *icon = NULL;
 
-  	const gchar *fallbacks_icon_menu[] = {
-		"open-menu-symbolic",
-		"emblem-system-symbolic",
+	const gchar *fallbacks_icon_menu[] = {
 		"open-menu",
 		"emblem-system",
+		"open-menu-symbolic",
+		"emblem-system-symbolic",
 		NULL,
 	};
 
@@ -443,18 +443,21 @@ pragha_window_new (PraghaApplication *pragha)
 	GtkWidget *playlist_statusbar_vbox, *vbox_main;
 	GtkWidget *menu_button;
 	GtkBuilder *menu_ui;
+	GtkCssProvider *css_provider;
 	GIcon *icon = NULL;
+	GError *error = NULL;
 	gint *win_size, *win_position;
+	gchar *css_filename = NULL;
 	gsize cnt = 0;
 
 	const GBindingFlags binding_flags =
 		G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL;
 
 	const gchar *fallbacks_icon_menu[] = {
-		"open-menu-symbolic",
-		"emblem-system-symbolic",
 		"open-menu",
 		"emblem-system",
+		"open-menu-symbolic",
+		"emblem-system-symbolic",
 		NULL,
 	};
 
@@ -631,6 +634,52 @@ pragha_window_new (PraghaApplication *pragha)
 
 	gtk_container_add(GTK_CONTAINER(window), vbox_main);
 
+	/* Attach the custum CSS to main window */
+
+	css_filename = g_build_path(G_DIR_SEPARATOR_S, g_get_user_config_dir(), "/pragha/custom.css", NULL);
+	if (g_file_test(css_filename, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_REGULAR))
+	{
+		css_provider = gtk_css_provider_new ();
+		gtk_css_provider_load_from_path (css_provider, css_filename, &error);
+
+		if (error == NULL)
+		{
+			gtk_style_context_add_provider_for_screen (gtk_widget_get_screen (GTK_WIDGET (window)),
+			                                           GTK_STYLE_PROVIDER (css_provider),
+			                                           GTK_STYLE_PROVIDER_PRIORITY_USER);
+		}
+		else
+		{
+			g_warning ("Could not attach user css style: %s", error->message);
+			g_error_free (error);
+		}
+
+		g_object_unref (css_provider);
+	}
+	g_free (css_filename);
+
+	css_filename = g_build_path(G_DIR_SEPARATOR_S, USRCUSTUMDIR, "custom.css", NULL);
+	if (g_file_test(css_filename, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_REGULAR))
+	{
+		css_provider = gtk_css_provider_new ();
+		gtk_css_provider_load_from_path (css_provider, css_filename, &error);
+
+		if (error == NULL)
+		{
+			gtk_style_context_add_provider_for_screen (gtk_widget_get_screen (GTK_WIDGET (window)),
+			                                           GTK_STYLE_PROVIDER (css_provider),
+			                                           GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+		}
+		else
+		{
+			g_warning ("Could not attach distro css style: %s", error->message);
+			g_error_free (error);
+		}
+
+		g_object_unref (css_provider);
+	}
+	g_free (css_filename);
+
 #if GTK_CHECK_VERSION (3, 12, 0)
 	if (!pragha_preferences_get_system_titlebar (preferences))
 		gtk_window_set_titlebar (GTK_WINDOW (window), GTK_WIDGET(toolbar));
